getCovNames: Get names of any covariates used in probability distribution parameters
Description
Get names of any covariates used in probability distribution parameters
Usage
getCovNames(m, p, distname)
Value
A list of:
DMtermsNames of all covariates included in the design matrix for the data stream
DMpartemsA list of the names of all covariates for each of the probability distribution parameters