Learn R Programming

momentuHMM (version 1.2.0)

plotPR: Plot pseudo-residuals

Description

Plots time series, qq-plots (against the standard normal distribution), and sample ACF functions of the pseudo-residuals for each data stream

Usage

plotPR(m, lag.max = NULL)

Arguments

m

A momentuHMM, miHMM, or miSum object.

lag.max

maximum lag at which to calculate the acf. See acf.

Details

  • If some turning angles in the data are equal to pi, the corresponding pseudo-residuals will not be included. Indeed, given that the turning angles are defined on (-pi,pi], an angle of pi results in a pseudo-residual of +Inf (check Section 6.2 of reference for more information on the computation of pseudo-residuals).

  • If some data streams are zero-inflated, the corresponding pseudo- residuals are shown as segments, because pseudo-residuals for discrete data are defined as segments (see Zucchini and MacDonald, 2009, Section 6.2).

  • Note that pseudo-residuals for multiple imputation analyses are based on pooled parameter estimates and the means of the data values across all imputations.

References

Zucchini, W. and MacDonald, I.L. 2009. Hidden Markov Models for Time Series: An Introduction Using R. Chapman & Hall (London).

Examples

Run this code
# NOT RUN {
# m is a momentuHMM object (as returned by fitHMM), automatically loaded with the package
m <- example$m

plotPR(m)

# }

Run the code above in your browser using DataLab