Learn R Programming

momentuHMM (version 1.4.3)

stationary: Stationary state probabilities

Description

Calculates the stationary probabilities of each state based on covariate values.

Usage

stationary(model, covs)

Arguments

model

momentuHMM, miHMM, or miSum object

covs

Either a data frame or a design matrix of covariates. If covs is not provided, then the stationary probabilties are calculated based on the covariate data for each time step.

Value

Matrix of stationary state probabilities. Each row corresponds to a row of covs, and each column corresponds to a state.

Examples

Run this code
# NOT RUN {
# m is a momentuHMM object (as returned by fitHMM), automatically loaded with the package
m <- example$m

# data frame of covariates
stationary(m, covs = data.frame(cov1 = 0, cov2 = 0))

# design matrix (each column corresponds to row of m$mle$beta)
stationary(m, covs = matrix(c(1,0,cos(0)),1,3))

# }

Run the code above in your browser using DataLab