Calculate distance between points y and z and turning angle between points x, y, and z
distAngle(x, y, z, type = "UTM", angleCov = TRUE)location 1
location 2
location 3
'UTM' if easting/northing provided (the default), 'LL' if longitude/latitude
logical indicating to not return NA when x=y or y=z. Default: TRUE (i.e. NA is not returned if x=y or y=z).
2-vector with first element the distance between y and z and second element the turning angle between (x,y) and (y,z).
Used in prepData and simData to get distance and turning angle covariates
between locations (x1,x2), (y1,y2) and activity center (z1,z2).
If type='LL' then distance is calculated as great circle distance using spDistsN1, and turning angle is calculated based on initial bearings using bearing.