These data are generated by the function exGen, and used in the examples and tests of
other functions to keep them as short as possible.
exampleexample is a list of the following objects for demonstrating fitHMM:
m A momentuHMM object
simPar The parameters used to simulate data
par0 The initial parameters in the optimization to fit m
miExample is a list of the following objects for demonstrating crawlWrap, MIfitHMM, and MIpool:
obsData Simulated observation data with measurement error and temporal irregularity (generated by simData)
bPar initial parameter estimates for MIfitHMM examples
forest is a simulated spatial covariate raster layer