Optional data frame consisting of a single row indicating the covariate values to be used in plots.
If none are specified, the means of any covariates appearing in the model are used (unless covariate is a factor, in which case the first factor in the data is used).
col
Vector or colors for the states (one color per state).
plotCI
Logical indicating whether to include confidence intervals in plots (default: FALSE)
alpha
Significance level of the confidence intervals (if plotCI=TRUE). Default: 0.95 (i.e. 95% CIs).
...
Additional arguments passed to plot. These can currently include cex.axis, cex.lab, cex.legend, cex.main, legend.pos, and lwd. See par. legend.pos can be a single keyword from the list ``bottomright'', ``bottom'', ``bottomleft'', ``left'', ``topleft'', ``top'', ``topright'', ``right'', and ``center''.