If some turning angles in the data are equal to pi, the corresponding pseudo-residuals
will not be included. Indeed, given that the turning angles are defined on (-pi,pi], an angle of pi
results in a pseudo-residual of +Inf (check Section 6.2 of reference for more information on the
computation of pseudo-residuals).
A continuity adjustment (adapted from Harte 2017) is made for discrete probability distributions. When
the data are near the boundary (e.g. 0 for ``pois''; 0 and 1 for ``bern''), then the pseudo residuals can
be a poor indicator of lack of fit.
Note that pseudo-residuals for multiple imputation analyses are based on pooled parameter
estimates and the means of the data values across all imputations.